@@ -22,27 +22,31 @@
 # Required parameters:
 #   MINOR	- root device minor number
 #   MAJOR	- root device major number
-SCRIPTANAME='/etc/init.d/vzquota'
 
-if [ -z "$MAJOR" ]; then
-	rc-update del vzquota default > /dev/null 2>&1
-	rm -f ${SCRIPTANAME} > /dev/null 2>&1
-	rm -f /etc/mtab > /dev/null 2>&1
-	ln -sf /proc/mounts /etc/mtab
-	exit 0
-fi
+setup_vzquota() {
+	SCRIPTANAME='/etc/init.d/vzquota'
 
-echo '#!/sbin/runscript
+	if [ -z "$MAJOR" ]; then
+		rc-update del vzquota default > /dev/null 2>&1
+		rm -f ${SCRIPTANAME} > /dev/null 2>&1
+		rm -f /etc/mtab > /dev/null 2>&1
+		ln -sf /proc/mounts /etc/mtab
+		exit 0
+	fi
+
+	cat << EOF > ${SCRIPTANAME} || exit 1
+#!/sbin/runscript
 
 start() {
-	[ -e "/dev/'${DEVFS}'" ] || mknod /dev/'${DEVFS}' b '$MAJOR' '$MINOR'
-	rm -f /etc/mtab >/dev/null 2>&1
-	echo "/dev/'${DEVFS}' / reiserfs rw,usrquota,grpquota 0 0" > /etc/mtab
-	mnt=`grep -v " / " /proc/mounts`
-	if [ $? = 0 ]; then
-		echo "$mnt" >> /etc/mtab
+	dev=\$(awk '(\$2 == "/") && (\$4 ~ /usrquota/) && (\$4 ~ /grpquota/) {print \$1}' /etc/mtab)
+	if test -z "\$dev"; then
+		dev="/dev/${DEVFS}"
+		rm -f /etc/mtab >/dev/null 2>&1
+		echo "/dev/${DEVFS} / reiserfs rw,usrquota,grpquota 0 0" > /etc/mtab
+		grep -v " / " /proc/mounts >> /etc/mtab 2>/dev/null
+		chmod 644 /etc/mtab
 	fi
-	chmod 644 /etc/mtab
+	[ -e "\$dev" ] || mknod \$dev b $MAJOR $MINOR
 	quotaon -aug
 	return
 }
@@ -50,13 +54,11 @@ start() {
 stop() {
 	return
 }
+EOF
+	chmod 755 ${SCRIPTANAME}
 
-' > ${SCRIPTANAME} || {
-	echo "Unable to create ${SCRIPTANAME}"
-	exit 1
+	rc-update add vzquota default
 }
-chmod 755 ${SCRIPTANAME}
-
-rc-update add vzquota default
 
+setup_quota
 exit 0
