@@ -45,6 +45,9 @@ typedef struct {
 	list_head_t list;
 } pci_param;
 
+int create_static_dev(const char *root, const char *name, const char *alias,
+		mode_t mode, dev_t dev);
+
 /** Allow/disallow access to devices on host system from CT.
  *
  * @param h		CT handler.
