@@ -49,7 +49,7 @@
 #include "image.h"
 
 static int _page_size;
-static int check_name(char *name);
+static int check_name(const char *name);
 
 static vps_config config[] = {
 /*	Op	*/
@@ -143,8 +143,11 @@ static vps_config config[] = {
 
 {"FEATURES",	NULL, PARAM_FEATURES},
 {"IOPRIO",	NULL, PARAM_IOPRIO},
+{"IOLIMIT",	NULL, PARAM_IOLIMIT},
+{"IOPSLIMIT",	NULL, PARAM_IOPSLIMIT},
 {"BOOTORDER",	NULL, PARAM_BOOTORDER},
 {"STOP_TIMEOUT", NULL, PARAM_STOP_TIMEOUT},
+{"VM_OVERCOMMIT", NULL, PARAM_VM_OVERCOMMIT},
 
 /* These ones are either known parameters for global config file,
  * or some obsoleted parameters used in the past. In both cases
@@ -161,6 +164,7 @@ static vps_config config[] = {
 {"IP6TABLES",		NULL, PARAM_IGNORED},
 {"CONFIG_CUSTOMIZED",	NULL, PARAM_IGNORED},
 {"VE_STOP_MODE",	NULL, PARAM_IGNORED},
+{"SKIP_SYSCTL_SETUP",	NULL, PARAM_IGNORED},
 
 {NULL,		NULL, -1}
 };
@@ -204,7 +208,7 @@ static int opt_get_by_id(struct option *opt, int id)
 	return -1;
 }
 
-static conf_struct *find_conf_line(list_head_t *head, char *name,
+static conf_struct *find_conf_line(list_head_t *head, const char *name,
 	char delim)
 {
 	conf_struct *conf;
@@ -222,6 +226,31 @@ static conf_struct *find_conf_line(list_head_t *head, char *name,
 	return NULL;
 }
 
+static long long get_mul(char c)
+{
+	switch (c) {
+	case 'T':
+	case 't':
+		return 1024ll * 1024 * 1024 * 1024;
+	case 'G':
+	case 'g':
+		return 1024 * 1024 * 1024;
+	case 'M':
+	case 'm':
+		return 1024 * 1024;
+	case 'K':
+	case 'k':
+		return 1024;
+	case 'P':
+	case 'p':
+		return _page_size;
+	case 'B':
+	case 'b':
+		return 1;
+	}
+	return -1;
+}
+
 static int parse_setmode(vps_param *vps_p, const char *val)
 {
 	if (!strcmp(val, "ignore"))
@@ -276,6 +305,20 @@ static int conf_parse_ulong(unsigned long **dst, const char *valstr)
 	return 0;
 }
 
+static int conf_parse_float(float **dst, const char *valstr)
+{
+	float val;
+	if (*dst != NULL)
+		return ERR_DUP;
+	if (sscanf(valstr, "%f", &val) != 1)
+		return ERR_INVAL;
+	*dst = malloc(sizeof(float));
+	if (*dst == NULL)
+		return ERR_NOMEM;
+	**dst = val;
+
+	return 0;
+}
 static int conf_parse_bitmap(unsigned long **dst, int nmaskbits,
 			     const char *valstr)
 {
@@ -308,8 +351,8 @@ static int conf_parse_guid(char **dst, const char *val)
 	return conf_parse_str(dst, guid);
 }
 
-static int conf_store_strlist(list_head_t *conf, char *name, list_head_t *val,
-		int allow_empty)
+static int conf_store_strlist(list_head_t *conf, const char *name,
+		list_head_t *val, int allow_empty)
 {
 	char *str;
 
@@ -324,7 +367,7 @@ static int conf_store_strlist(list_head_t *conf, char *name, list_head_t *val,
 	return 0;
 }
 
-static int conf_store_str(list_head_t *conf, char *name, const char *val)
+static int conf_store_str(list_head_t *conf, const char *name, const char *val)
 {
 	char *buf;
 	int len;
@@ -341,14 +384,15 @@ static int conf_store_str(list_head_t *conf, char *name, const char *val)
 	return 0;
 }
 
-static int conf_store_yesno(list_head_t *conf, char *name, int val)
+static int conf_store_yesno(list_head_t *conf, const char *name, int val)
 {
 	if (!val)
 		return 0;
 	return conf_store_str(conf, name, val == YES ? "yes" : "no");
 }
 
-static int conf_store_ulong(list_head_t *conf, char *name, unsigned long *val)
+static int conf_store_ulong(list_head_t *conf, const char *name,
+		unsigned long *val)
 {
 	char buf[] = "18446744073709551615"; /* ULONG_MAX on 64 bit */
 
@@ -359,7 +403,7 @@ static int conf_store_ulong(list_head_t *conf, char *name, unsigned long *val)
 	return conf_store_str(conf, name, buf);
 }
 
-static int conf_store_int(list_head_t *conf, char *name, int val)
+static int conf_store_int(list_head_t *conf, const char *name, int val)
 {
 	char buf[] = "2147483647"; /* INT_MAX */
 
@@ -367,7 +411,15 @@ static int conf_store_int(list_head_t *conf, char *name, int val)
 	return conf_store_str(conf, name, buf);
 }
 
-static int conf_store_bitmap(list_head_t *conf, char *name,
+static int conf_store_float(list_head_t *conf, const char *name, float val)
+{
+	char buf[] = "1.34567e+12";
+
+	snprintf(buf, sizeof(buf), "%g", val);
+	return conf_store_str(conf, name, buf);
+}
+
+static int conf_store_bitmap(list_head_t *conf, const char *name,
 			     unsigned long *val, int nmaskbits)
 {
 	int ret;
@@ -427,7 +479,7 @@ static void store_features(unsigned long long mask, unsigned long long known,
 	add_str_param(conf_h, buf);
 }
 
-static int parse_ioprio(int id, io_param *io, char *val)
+static int parse_ioprio(io_param *io, char *val)
 {
 	if (parse_int(val, &io->ioprio))
 		return ERR_INVAL;
@@ -438,15 +490,97 @@ static int parse_ioprio(int id, io_param *io, char *val)
 	return 0;
 }
 
-static int store_ioprio(vps_param *old_p, vps_param *vps_p,
+static int parse_iolimit(io_param *io, char *val, int def_mul)
+{
+	char *tail;
+	unsigned long long tmp;
+	long long n;
+	int ret = 0;
+
+	if (!strcmp(val, "unlimited")) {
+		io->iolimit = 0;
+		return 0;
+	}
+
+	errno = 0;
+	tmp = strtoull(val, &tail, 10);
+	if (errno == ERANGE)
+		goto inval;
+
+	if (tmp > INT_MAX) {
+		tmp = INT_MAX;
+		ret = ERR_LONG_TRUNC;
+	}
+
+	if (*tail != '\0') {
+		n = get_mul(*tail++);
+
+		if ((n < 0) || (*tail != '\0'))
+			goto inval;
+
+		tmp = tmp * n;
+	} else {
+		tmp *= def_mul;
+	}
+
+	/* After multiplication, truncate again */
+	if (tmp > INT_MAX) {
+		tmp = INT_MAX;
+		ret = ERR_LONG_TRUNC;
+	}
+
+	io->iolimit = tmp;
+
+	return ret;
+
+inval:
+	io->iolimit = -1;
+
+	return ERR_INVAL;
+}
+
+static int parse_iopslimit(io_param *io, char *val)
+{
+	int tmp;
+
+	if (parse_int(val, &tmp))
+		goto inval;
+
+	if (tmp < 0)
+		goto inval;
+
+	io->iopslimit = tmp;
+
+	return 0;
+
+inval:
+	io->iopslimit = -1;
+
+	return ERR_INVAL;
+}
+
+static int store_io(vps_param *old_p, vps_param *vps_p,
 				 vps_config *conf, list_head_t *conf_h)
 {
 	io_param *io_param = &vps_p->res.io;
+	int val = -1;
 
-	if (conf->id != PARAM_IOPRIO || io_param->ioprio < 0)
+	switch (conf->id) {
+		case PARAM_IOPRIO:
+			val = io_param->ioprio;
+			break;
+		case PARAM_IOLIMIT:
+			val = io_param->iolimit;
+			break;
+		case PARAM_IOPSLIMIT:
+			val = io_param->iopslimit;
+			break;
+	}
+
+	if (val < 0)
 		return 0;
 
-	return conf_store_int(conf_h, conf->name, io_param->ioprio);
+	return conf_store_int(conf_h, conf->name, val);
 }
 
 /******************** Iptables *************************/
@@ -506,30 +640,6 @@ static int store_env(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 }
 
 /********************** UB **************************************/
-static long long get_mul(char c)
-{
-	switch (c) {
-	case 'T':
-	case 't':
-		return 1024ll * 1024 * 1024 * 1024;
-	case 'G':
-	case 'g':
-		return 1024 * 1024 * 1024;
-	case 'M':
-	case 'm':
-		return 1024 * 1024;
-	case 'K':
-	case 'k':
-		return 1024;
-	case 'P':
-	case 'p':
-		return _page_size;
-	case 'B':
-	case 'b':
-		return 1;
-	}
-	return -1;
-}
 
 /* This function parses string in form xxx[GMKPB]
  */
@@ -760,6 +870,11 @@ if (ub->res != NULL) {							\
 	ADD_UB_PARAM(swappages, PARAM_SWAPPAGES)
 #undef ADD_UB_PARAM
 
+	if (ub->vm_overcommit && ub->vm_overcommit != 0) {
+		conf = conf_get_by_id(config, PARAM_VM_OVERCOMMIT);
+		conf_store_float(conf_h, conf->name, *ub->vm_overcommit);
+	}
+
 	return 0;
 }
 
@@ -1414,7 +1529,8 @@ static inline int parse_cpumask(cpumask_t **dst, const char *str)
 	return conf_parse_bitmap((unsigned long **)dst, CPUMASK_NBITS, str);
 }
 
-static inline int store_cpumask(list_head_t *conf, char *name, cpumask_t *val)
+static inline int store_cpumask(list_head_t *conf, const char *name,
+		cpumask_t *val)
 {
 	return conf_store_bitmap(conf, name, cpumask_bits(val), CPUMASK_NBITS);
 }
@@ -2045,6 +2161,9 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 		ret = parse_vswap(&vps_p->res.ub, val, id,
 				vps_p->opt.save_force);
 		break;
+	case PARAM_VM_OVERCOMMIT:
+		ret = conf_parse_float(&vps_p->res.ub.vm_overcommit, val);
+		break;
 	case PARAM_CAP:
 		ret = parse_cap(val, &vps_p->res.cap);
 		break;
@@ -2202,8 +2321,19 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 		ret = parse_features(&vps_p->res.env, val);
 		break;
 	case PARAM_IOPRIO:
-		if (parse_ioprio(id, &vps_p->res.io, val))
-			return ERR_INVAL;
+		ret = parse_ioprio(&vps_p->res.io, val);
+		break;
+	case PARAM_IOLIMIT:
+	case PARAM_IOLIMIT_MB:
+		ret = parse_iolimit(&vps_p->res.io, val,
+				/* value from cmdline is in MB/s
+				 * unless a suffix is provided;
+				 * value from config is in B/s.
+				 */
+				(id == PARAM_IOLIMIT_MB) ? 1024*1024 : 1);
+		break;
+	case PARAM_IOPSLIMIT:
+		ret = parse_iopslimit(&vps_p->res.io, val);
 		break;
 	case PARAM_BOOTORDER:
 		ret = conf_parse_ulong(&vps_p->res.misc.bootorder, val);
@@ -2237,6 +2367,7 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 		if (int_id < 0)
 			return ERR_INVAL;
 		vps_p->res.misc.stop_timeout = int_id;
+		break;
 	case PARAM_IGNORED:
 		/* Well known but ignored parameter */
 		break;
@@ -2268,7 +2399,7 @@ static int store(vps_param *old_p, vps_param *vps_p, list_head_t *conf_h)
 		store_meminfo(old_p, vps_p, conf, conf_h);
 		store_netif(old_p, vps_p, conf, conf_h);
 		store_name(old_p, vps_p, conf, conf_h);
-		store_ioprio(old_p, vps_p, conf, conf_h);
+		store_io(old_p, vps_p, conf, conf_h);
 	}
 	return 0;
 }
@@ -2592,6 +2723,8 @@ vps_param *init_vps_param()
 	list_head_init(&param->del_res.veth.dev);
 	param->res.meminfo.mode = -1;
 	param->res.io.ioprio = -1;
+	param->res.io.iolimit = -1;
+	param->res.io.iopslimit = -1;
 	param->opt.mode = -1;
 	param->res.misc.stop_timeout = -1;
 
@@ -2623,9 +2756,9 @@ int get_veid_by_name(const char *name)
 	return -1;
 }
 
-static int check_name(char *name)
+static int check_name(const char *name)
 {
-	char *p;
+	const char *p;
 	const char *validchars = " -+_.";
 
 	for (p = name; *p != '\0'; p++) {
@@ -2847,6 +2980,12 @@ static void merge_opt(vps_opt *dst, vps_opt *src)
 	MERGE_STR(apply_cfg)
 }
 
+void merge_ub(ub_param *dst, ub_param *src)
+{
+	FOR_ALL_UBC(MERGE_P2)
+	MERGE_P(vm_overcommit)
+}
+
 static void merge_fs(fs_param *dst, fs_param *src)
 {
 	MERGE_STR(root)
@@ -2975,6 +3114,8 @@ static void merge_name(name_param *dst, name_param *src)
 
 static void merge_io(io_param *dst, io_param *src) {
 	MERGE_INT2(ioprio)
+	MERGE_INT2(iolimit)
+	MERGE_INT2(iopslimit)
 }
 
 static int merge_res(vps_res *dst, vps_res *src)
