@@ -29,11 +29,20 @@
 #include "logger.h"
 #include "vzerror.h"
 
+/* Check if CT private area is mounted
+ * Returns:
+ *   1: mounted
+ *   0: not mounted
+ *  -1: error getting status
+ */
 int vps_is_mounted(const char *root, const char *private)
 {
 	struct stat st1, st2;
 	char parent[PATH_MAX];
 
+	if (!root || !private)
+		return -1;
+
 	if (stat(root, &st1)) {
 		logger(-1, errno, "stat(%s)", root);
 		return -1;
@@ -51,6 +60,9 @@ int vps_is_mounted(const char *root, const char *private)
 
 	/* Check for bind mount (upstream case) */
 	if (stat(private, &st2)) {
+		/* return false when private area does not exist */
+		if (errno == ENOENT)
+			return 0;
 		logger(-1, errno, "stat(%s)", private);
 		return -1;
 	}
