@@ -260,7 +260,7 @@ static int vz_do_env_create(struct arg_start *arg)
 		if (fn == NULL) {
 			ret = _env_create(h, (void *)arg);
 		} else {
-			ret = fn(h, veid, &res->fs, wait_p, old_wait_p, err_p, data);
+			ret = fn(h, veid, res, wait_p, old_wait_p, err_p, data);
 		}
 env_err:
 		if (ret)
@@ -602,6 +602,19 @@ err_out:
 	return VZ_CHKPNT_ERROR;
 }
 
+#define GET_DUMP_FILE(req_cmd)							\
+do {										\
+	dumpfile = param->dumpfile;						\
+	if (dumpfile == NULL) {							\
+		if (cmd == req_cmd) {						\
+			logger(-1,  0, "Error: dumpfile is not specified");	\
+			goto err;						\
+		}								\
+		get_dump_file(veid, param->dumpdir, buf, sizeof(buf));		\
+		dumpfile = buf;							\
+	}									\
+} while (0)
+
 static int vz_chkpnt(vps_handler *h, envid_t veid,
 		     const fs_param *fs, int cmd, cpt_param *param)
 {
@@ -700,13 +713,14 @@ err:
 	return ret;
 }
 
-static int restore_fn(vps_handler *h, envid_t veid, const fs_param *fs,
+static int restore_fn(vps_handler *h, envid_t veid, const vps_res *res,
 			int wait_p, int old_wait_p, int err_p, void *data)
 {
 	int status, len, len1, ret;
 	cpt_param *param = (cpt_param *) data;
 	char buf[PIPE_BUF];
 	int error_pipe[2];
+	const char *fail = "";
 
 	status = VZ_RESTORE_ERROR;
 	if (param == NULL)
@@ -750,7 +764,7 @@ static int restore_fn(vps_handler *h, envid_t veid, const fs_param *fs,
 
 	logger(0, 0, "\tundump...");
 	if (ioctl(param->rst_fd, CPT_UNDUMP, 0) != 0) {
-		logger(-1, errno, "Error: undump failed");
+		fail = "undump failed";
 		goto err_undump;
 	}
 	/* Now we wait until CT setup will be done */
@@ -759,13 +773,13 @@ static int restore_fn(vps_handler *h, envid_t veid, const fs_param *fs,
 		clean_hardlink_dir("/");
 		logger(0, 0, "\tresume...");
 		if (ioctl(param->rst_fd, CPT_RESUME, 0)) {
-			logger(-1, errno, "Error: resume failed");
+			fail = "resume failed";
 			goto err_undump;
 		}
 	} else if (param->cmd == CMD_UNDUMP && !param->ctx) {
 		logger(0, 0, "\tget context...");
 		if (ioctl(param->rst_fd, CPT_GET_CONTEXT, veid) < 0) {
-			logger(-1, errno, "Can not get context");
+			fail = "can not get context";
 			goto err_undump;
 		}
 	}
@@ -779,7 +793,7 @@ err_pipe:
 	return status;
 
 err_undump:
-	logger(-1, 0, "Restoring failed:");
+	logger(-1, errno, "Restore error, %s", fail);
 	while ((len = read(error_pipe[0], buf, PIPE_BUF)) > 0) {
 		do {
 			len1 = write(STDERR_FILENO, buf, len);
@@ -833,7 +847,7 @@ static int vz_restore(vps_handler *h, envid_t veid, vps_param *vps_p,
 	param->rst_fd = rst_fd;
 	param->cmd = cmd;
 	ret = vps_start_custom(h, veid, vps_p,
-			SKIP_CONFIGURE | SKIP_ACTION_SCRIPT | skip,
+			SKIP_CONFIGURE | skip,
 			NULL, restore_fn, param);
 	if (ret)
 		goto err;
@@ -843,13 +857,15 @@ err:
 		close(dump_fd);
 	if (!ret) {
 		logger(0, 0, "Restoring completed successfully");
-		if (cmd == CMD_RESTORE)
-			if (dumpfile)
-				unlink(dumpfile);
+		if ((cmd == CMD_RESTORE) && (dumpfile) &&
+				!(skip & SKIP_DUMPFILE_UNLINK))
+			unlink(dumpfile);
 	}
 	return ret;
 }
 
+#undef GET_DUMP_FILE
+
 int vz_do_open(vps_handler *h, vps_param *param)
 {
 	if ((h->vzfd = open(VZCTLDEV, O_RDWR)) < 0) {
