@@ -913,6 +913,15 @@ static int check_set_opt(int argc, char *argv[], vps_param *param)
 		return VZ_INVALID_PARAMETER_SYNTAX;
 	}
 
+	/* VSwap config requires SWAPPAGES to be set */
+	if ((is_vswap_config(&param->res.ub) ||
+			is_vswap_config(&param->g_param->res.ub)) &&
+			(!param->res.ub.swappages &&
+			 !param->g_param->res.ub.swappages)) {
+		logger(-1, 0, "Error: required UB parameter (swap) not set");
+		return VZ_NOTENOUGHUBCPARAMS;
+	}
+
 	/* A few options require --save flag */
 	if (!param->opt.save) {
 		if (param->res.name.name != NULL) {
@@ -1175,14 +1184,17 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 		ub_param calc_ub = {};
 
 		merge_ub(&calc_ub, &cmd_p->res.ub);
-		fill_vswap_ub(&g_p->res.ub, &calc_ub);
+		ret = fill_vswap_ub(&g_p->res.ub, &calc_ub);
+		if (!ret) {
 
-		/* If CT is not running, call this anyway to get relevant
-		 * errors messages like "Can't set CPU: CT is not running"
-		 */
-		ret = vps_setup_res(h, veid, actions,
+			/* If CT is not running, call this anyway
+			 * to get relevant errors messages like
+			 * "Can't set CPU: CT is not running"
+			 */
+			ret = vps_setup_res(h, veid, actions,
 				&g_p->res.fs, &calc_ub, cmd_p,
 				STATE_RUNNING, SKIP_NONE, &g_action);
+		}
 		free_ub_param(&calc_ub);
 	}
 err:
