@@ -99,7 +99,8 @@ static void usage(int rc)
 "   [--netif_add <ifname[,mac,host_ifname,host_mac,bridge]]>]\n"
 "   [--netif_del <ifname>]\n"
 "   [--applyconfig <name>] [--applyconfig_map <name>]\n"
-"   [--features <name:on|off>] [--name <vename>] [--ioprio <N>]\n"
+"   [--features <name:on|off>] [--name <vename>]\n"
+"   [--ioprio <N>] [--iolimit <N>] --iopslimit <N>\n"
 "   [--pci_add [<domain>:]<bus>:<slot>.<func>] [--pci_del <d:b:s.f>]\n"
 "   [--iptables <name>] [--disabled <yes|no>]\n"
 "   [--stop-timeout <seconds>\n"
